@@ -1470,13 +1470,20 @@ find_formula_id(name_p) char *name_p;
 /*    difference to see if it was satisfied */
 /* RETURN:   0 no error */
 /*           1 error    */
+/*           2 parse error */
 int
 f_eval_formula(f_val, f_str, v_str, pt_str) double *f_val;char *f_str;char *v_str; char *pt_str;
 {
   int  var_cnt;
-  
+  extern  int        ErrorMsg_count;
+  extern  char *     ErrorMsg_p;
   /* before setup formula symbol tree, make sure it is clean */
-  
+  if(ErrorMsg_p) { 
+    capa_mfree(ErrorMsg_p);
+    ErrorMsg_p = NULL;
+    ErrorMsg_count = 0;
+  }
+
   var_cnt = setup_formula_id(v_str,pt_str);
   /* printf("\nSETUP formula ID (%s),(%s) returned %d\n",v_str,pt_str,var_cnt); */
   /* copy the formula into lexer buffer */
@@ -1486,6 +1493,9 @@ f_eval_formula(f_val, f_str, v_str, pt_str) double *f_val;char *f_str;char *v_st
     FormulaParseOK = 1;
     fml_parse(); /* main entry point */
     if( FormulaParseOK ) {
+      if( ErrorMsg_count > 0 ) {
+	return (2);
+      }
       *f_val = FormulaVal;
       /* printf("\nEVAL formulaOK = (%.16g)\n",FormulaVal); */
       return (0);
@@ -1517,6 +1527,7 @@ int  f_str_to_numbers(f_ar, n_str) double **f_ar; char *n_str;
   double     tmp_farray[ONE_K];
   double    *f_array;
   
+  *f_ar = NULL;
   if (n_str == NULL) {
     return (0);
   }
@@ -1870,15 +1881,22 @@ new_ptslist( sp ) Symbol *sp;
 PointsList_t *
 gen_ptslist_str( range_str ) char *range_str;
 {
-  char         *colon, *pound, *cp;
+  char         *semicolon, *colon, *pound, *cp;
   char          p1[ONE_K], p2[ONE_K], num[ONE_K];
   int           i, pts_cnt;
   PointsList_t *ptp;
   
   ptp = NULL;
-  colon = strchr(range_str,':');
-  pound = strchr(range_str,'#');
-  if( (colon) && (pound)) { /* we must have both ':' and '#' */
+  semicolon = strchr(range_str,';');
+  colon     = strchr(range_str,':');
+  pound     = strchr(range_str,'#');
+  if( (colon) 
+      && (pound) 
+      && (!semicolon 
+	  || ( 
+	      (colon < semicolon)
+	      && (pound < semicolon) ))) { 
+    /* we must have both ':' and '#' and they both must occur before any ';' */
     cp = range_str;
     i  = 0;
     while( isspace(*cp) || (*cp == '"') ) { cp++; }
@@ -1908,10 +1926,12 @@ gen_ptslist_str( range_str ) char *range_str;
       p1[i++] =  *cp; cp++;
     }
     p1[i] = 0;
-    ptp = (PointsList_t *)capa_malloc(1,sizeof(PointsList_t)); /* *** */
-    ptp->pts_str   = strsave(p1);
-    ptp->pts_idx   = 1;
-    ptp->pts_next  = NULL;
+    if (i != 0) {
+      ptp = (PointsList_t *)capa_malloc(1,sizeof(PointsList_t)); /* *** */
+      ptp->pts_str   = strsave(p1);
+      ptp->pts_idx   = 1;
+      ptp->pts_next  = NULL;
+    }
   }
   return (ptp);
 }
