@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.103 2008/05/30 19:31:20 bisitz Exp $
+# $Id: lonlogin.pm,v 1.104 2008/07/08 17:56:21 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -507,6 +507,10 @@ ENDNOOPT
         $logintitle = '<td bgcolor="'.$sidebg.'" colspan="2"><img src="'.$login.'" alt="'.
                       &mt('User Authentication').'" /></td>';
     }
+    my $noscript_warning='<td colspan="2" bgcolor="'.$mainbg.'">'
+                        .'<noscript><div class="LC_warning"><font size="-1">'
+                        .&mt('Use of LON-CAPA requires Javascript to be enabled in your web browser.')
+                        .'</font></div></noscript></td>';
     $r->print(<<ENDLOGIN);
      <input type="hidden" name="lextkey" value="$lextkey">
      <input type="hidden" name="uextkey" value="$uextkey">
@@ -514,6 +518,7 @@ ENDNOOPT
      <!-- Start the sub-table for text and input alignment -->
      <table border=0 cellspacing=0 cellpadding=0>
       <tr>$logintitle</tr>
+      <tr>$noscript_warning</tr>
       <tr>
        <td bgcolor="$mainbg"><br /><font size=-1><b>&nbsp;&nbsp;&nbsp;<label for="uname">$lt{'un'}</label>:</b></font></td>
        <td bgcolor="$mainbg"><br /><input type="text" name="uname" size="10" value="$authusername" /></td>
