@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.30 2008/04/02 12:29:38 bisitz Exp $
+# $Id: lonlogout.pm,v 1.31 2008/05/13 15:06:34 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -49,6 +49,10 @@ sub handler {
     }
 
     #we've got a valid user
+    #any locks in place?
+    my $locknum=&Apache::lonnet::get_locks();
+    if ($locknum) { return 409; }
+    #nope, go ahead
     my @profile;
     my $lonidsdir=$r->dir_config('lonIDsDir');
     &Apache::lonnet::transfer_profile_to_env($lonidsdir,$handle);
