@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.200 2008/07/08 20:16:16 raeburn Exp $
+# $Id: lonroles.pm,v 1.202 2008/07/18 16:17:39 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -43,6 +43,7 @@ use Apache::lonpageflip();
 use Apache::lonnavdisplay();
 use GDBM_File;
 use LONCAPA qw(:DEFAULT :match);
+use HTML::Entities;
  
 
 sub redirect_user {
@@ -675,7 +676,8 @@ ENDHEADER
     } else {
         if ($countactive > 0) {
             my $domdesc = &Apache::lonnet::domain($env{'user.domain'},'description');
-            $r->print('<p>'.&mt('[_1]Visit the [_2]Course Catalog[_3] to view all [_4] LON-CAPA courses.','<b>','<a href="/adm/coursecatalog">','</a></b>',$domdesc).'<br />'.&mt('If a course is [_1]not[_2] in your list of current courses below, you may be able to enroll if self-enrollment is permitted.','<b>','</b>').'</p>');
+            my $esc_dom = &HTML::Entities::encode($env{'user.domain'},'"<>&'); 
+            $r->print('<p>'.&mt('[_1]Visit the [_2]Course Catalog[_3] to view all [_4] LON-CAPA courses.','<b>','<a href="/adm/coursecatalog?showdom='.$esc_dom.'">','</a></b>',$domdesc).'<br />'.&mt('If a course is [_1]not[_2] in your list of current courses below, you may be able to enroll if self-enrollment is permitted.','<b>','</b>').'</p>');
         }
     }
 
@@ -712,19 +714,31 @@ ENDHEADER
         $r->print(&Apache::loncommon::end_page());
 	return OK;
 # Is there only one choice?
-    } elsif (($countactive==1) && ($env{'request.role'} eq 'cm')) {
-	$r->print('<h3>'.&mt('Please stand by.').'</h3>'.
-	    '<input type="hidden" name="'.$possiblerole.'" value="1" />'.
+    } elsif ($countactive==1) {
+        my $needs_switchserver;
+        if ($env{'user.author'}) {
+            $needs_switchserver = &check_needs_switchserver($possiblerole);
+        }
+        if ((!$needs_switchserver) && ($env{'request.role'} eq 'cm')) {
+	    $r->print('<h3>'.&mt('Please stand by.').'</h3>'.
+	        '<input type="hidden" name="'.$possiblerole.'" value="1" />'.
             '<noscript><br /><input type="submit" name="submit" value="'.&mt('Continue').'" /></noscript>');
-	$r->print("</form>\n");
-	$r->rflush();
-	$r->print('<script type="text/javascript">document.forms.rolechoice.submit();</script>');
-	$r->print(&Apache::loncommon::end_page());
-	return OK;
+	    $r->print("</form>\n");
+	    $r->rflush();
+	    $r->print('<script type="text/javascript">document.forms.rolechoice.submit();</script>');
+	    $r->print(&Apache::loncommon::end_page());
+	    return OK;
+        }
+        if ($needs_switchserver) {
+            $r->print("<h2>".&mt('Server Switch Required')."</h2>\n".
+                      &mt('Construction Space access is only available from '.
+                          'the home server of the corresponding Author.').'<br />'.
+                      &mt("Click the 'Switch Server' link to go there.").'<br />');   
+        }
     }
 # More than one possible role
 # ----------------------------------------------------------------------- Table
-    unless ((!&Apache::lonmenu::show_course()) || ($nochoose)) {
+    unless ((!&Apache::lonmenu::show_course()) || ($nochoose) || ($countactive==1)) {
 	$r->print("<h2>".&mt('Select a Course to Enter')."</h2>\n");
     }
     my $doheaders = &roletable_headers($r,\%roleclass,\%sortrole,$nochoose);
@@ -759,27 +773,28 @@ ENDHEADER
                   &Apache::loncommon::authorbrowser_javascript());
     }
     &print_rolerows($r,$doheaders,\%roleclass,\%sortrole,\%dcroles,\%roletext);
-    my $tremark='';
-    my $tfont='#003300';
-    if ($env{'request.role'} eq 'cm') {
-	$r->print('<tr bgcolor="#11CC55">');
-        $tremark=&mt('Currently selected. ');
-        $tfont='#002200';
-    } else {
-        $r->print('<tr bgcolor="#77FF77">');
-    }
-    unless ($nochoose) {
-	if ($env{'request.role'} ne 'cm') {
-	    $r->print('<td><input type="submit" value="'.
-		      &mt('Select').'" name="cm" /></td>');
-	} else {
-	    $r->print('<td>&nbsp;</td>');
-	}
-    }
-    $r->print('<td colspan="3"><font color="'.$tfont.'"><span class="LC_rolesinfo">'.&mt('No role specified').
-      '</span></font></td><td><font color="'.$tfont.'">'.$tremark.
-      '&nbsp;</font></td></tr>'."\n");
-
+    if ($countactive > 1) {
+        my $tremark='';
+        my $tfont='#003300';
+        if ($env{'request.role'} eq 'cm') {
+	    $r->print('<tr bgcolor="#11CC55">');
+            $tremark=&mt('Currently selected. ');
+            $tfont='#002200';
+        } else {
+            $r->print('<tr bgcolor="#77FF77">');
+        }
+        unless ($nochoose) {
+	    if ($env{'request.role'} ne 'cm') {
+	        $r->print('<td><input type="submit" value="'.
+		          &mt('Select').'" name="cm" /></td>');
+	    } else {
+	        $r->print('<td>&nbsp;</td>');
+	    }
+        }
+        $r->print('<td colspan="3"><font color="'.$tfont.'"><span class="LC_rolesinfo">'.&mt('No role specified').
+                  '</span></font></td><td><font color="'.$tfont.'">'.$tremark.
+                  '&nbsp;</font></td></tr>'."\n");
+    } 
     $r->print('</table>');
     unless ($nochoose) {
 	$r->print("</form>\n");
@@ -791,11 +806,13 @@ ENDHEADER
     }
     $r->print(&Apache::lonnet::getannounce());
     if ($advanced) {
+        my $esc_dom = &HTML::Entities::encode($env{'user.domain'},'"<>&');
 	$r->print('<p><small><i>'
                  .&mt('This is LON-CAPA [_1]',$r->dir_config('lonVersion'))
 		 .'</i><br />'
 		 .'<a href="/adm/logout">'.&mt('Logout').'</a>&nbsp;&nbsp;'
-                 .'<a href="/adm/coursecatalog">'.&mt('Course Catalog')
+                 .'<a href="/adm/coursecatalog?showdom='.$esc_dom.'">'
+                 .&mt('Course Catalog')
                  .'</small></p>');
     }
     $r->print(&Apache::loncommon::end_page());
@@ -866,6 +883,7 @@ sub print_rolerows {
 sub findcourse_advice {
     my ($r) = @_;
     my $domdesc = &Apache::lonnet::domain($env{'user.domain'},'description');
+    my $esc_dom = &HTML::Entities::encode($env{'user.domain'},'"<>&');
     if (&Apache::lonnet::auto_run(undef,$env{'user.domain'})) {
         $r->print(&mt('If you were expecting to see an active role listed for a particular course in the [_1] domain, it may be missing for one of the following reasons:',$domdesc).'
 <ul>
@@ -878,7 +896,7 @@ sub findcourse_advice {
     } else {
         $r->print(&mt('If you were expecting to see an active role listed for a particular course, that course may not have been created yet.').'<br />');
     }
-    $r->print('<p>'.&mt('The [_1]Course Catalog[_2] provides information about all [_3] classes for which LON-CAPA courses have been created.','<a href="/adm/coursecatalog">','</a>',$domdesc).'<br />');
+    $r->print('<p>'.&mt('The [_1]Course Catalog[_2] provides information about all [_3] classes for which LON-CAPA courses have been created.','<a href="/adm/coursecatalog?showdom='.$esc_dom.'">','</a>',$domdesc).'<br />');
     $r->print(&mt('You can search the course catalog for courses which permit self-enrollment, if you would like to enroll in a course.').'</p>');
     return;
 }
@@ -1014,6 +1032,24 @@ sub build_roletext {
     return $roletext;
 }
 
+sub check_needs_switchserver {
+    my ($possiblerole) = @_;
+    my $needs_switchserver;
+    my ($role,$where) = split(/\./,$possiblerole,2);
+    my (undef,$tdom,$twho) = split(/\//,$where);
+    my ($server_status,$home);
+    if (($role eq 'ca') || ($role eq 'aa')) {
+        ($server_status,$home) = &check_author_homeserver($twho,$tdom);
+    } else {
+        ($server_status,$home) = &check_author_homeserver($env{'user.name'},
+                                                          $env{'user.domain'});
+    }
+    if ($server_status eq 'switchserver') {
+        $needs_switchserver = 1;
+    }
+    return $needs_switchserver;
+}
+
 sub check_author_homeserver {
     my ($uname,$udom)=@_;
     if (($uname eq '') || ($udom eq '')) {
@@ -1069,8 +1105,8 @@ sub check_fordc {
 sub adhoc_course_role {
     my ($then) = @_; 
     my ($cdom,$cnum);
-    my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
-    my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
+    $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
+    $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
     if (&check_forcc($cdom,$cnum,$then)) {
         my $setprivs;
         if (!defined($env{'user.role.'.$env{'form.switchrole'}})) {
