@@ -1,4 +1,4 @@
-# $Id: imagechoice.pm,v 1.13 2007/05/02 01:33:02 albertel Exp $
+# $Id: imagechoice.pm,v 1.14 2008/03/12 02:46:53 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -165,7 +165,7 @@ sub savecoord {
 	    $data=join(':',($env{"imagechoice.$id.coords"},
 			    $env{"form.image.x"},$env{"form.image.y"}));
 	}
-	&Apache::lonnet::appenv("imagechoice.$id.coords"=>$data);
+	&Apache::lonnet::appenv({"imagechoice.$id.coords"=>$data});
     }
     return int(scalar(split(':',$env{"imagechoice.$id.coords"}))/2);
 }
@@ -237,7 +237,7 @@ sub drawimage {
     &drawX(\%data,$imid,$x,$y);
     if ($type eq "polygon") { &drawPolygon(\%data,$id,$imid); }
     if ($type eq "box") { &drawBox(\%data,$id,$imid); }
-    &Apache::lonnet::appenv(%data);
+    &Apache::lonnet::appenv(\%data);
     return "/adm/randomlabel.png?token=$imid"
 }
 
