@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.243 2008/05/22 22:04:31 www Exp $
+# $Id: inputtags.pm,v 1.244 2008/07/26 19:11:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -849,7 +849,12 @@ sub decideoutput {
 	$added_computer_text=1;
     }
     if ($Apache::lonhomework::type eq 'practice') {
-       $message.='<br />'.&mt('Submissions to practice problems are not permanently recorded.');
+       if ($target eq 'web') {
+           $message .= '<br />';
+       } else {
+           $message .= ' ';      
+       }
+       $message.=&mt('Submissions to practice problems are not permanently recorded.');
     }
 
     return ($button,$css_class,$message,$previousmsg);
@@ -1081,7 +1086,7 @@ sub grade {
 	    my ($match) =
 		&previous_match(\@Apache::inputtags::previous_version,
 				scalar(@Apache::inputtags::response));
-	    
+
 	    if ($match) {
 		$previously_used = 'PREVIOUSLY_LAST';
 		foreach my $value (@Apache::inputtags::previous) {
