@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.293 2008/05/19 21:07:33 www Exp $
+# $Id: lonhomework.pm,v 1.296 2008/07/28 05:26:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -935,8 +935,11 @@ sub editxmlmode {
 	my $js =
 	    &Apache::edit::js_change_detection(). 
 	    &Apache::loncommon::resize_textarea_js().
-            &Apache::structuretags::setmode_javascript();
+            &Apache::structuretags::setmode_javascript().
+            &Apache::lonhtmlcommon::dragmath_js();
 	my $only_body =  ($env{'environment.remote'} eq 'off')? 0 : 1;
+	my $dragmath_button = 
+            &Apache::lonhtmlcommon::dragmath_button("LC_editxmltext",1);
 	my $start_page = 
 	    &Apache::loncommon::start_page(&mt("EditXML [_1]",$file),$js,
 					   {'no_auto_mt_title' => 1,
@@ -959,10 +962,12 @@ sub editxmlmode {
               </table>
               <div class="LC_edit_problem_discards">
                 <input type="hidden" name="problemmode" value="editxml" />
+
                 <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
                 'onclick="javascript:setmode(this.form,'."'discard'".')" />
                 <input type="button" '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'edit'".')').'name="submitmode" accesskey="e" value="'.&mt('Edit').'" />
                 <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
+                '.$dragmath_button.'
               </div>
               <div class="LC_edit_problem_saves">
                 <input type="submit" name="submitbutton" accesskey="s" value="'.&mt('Save').'"  />
