@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Interface routines to MAXIMA CAS
 #
-# $Id: lonmaxima.pm,v 1.21 2007/08/14 21:54:54 riegler Exp $
+# $Id: lonmaxima.pm,v 1.23 2008/06/14 16:34:54 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,11 +70,39 @@ sub blacklisted {
     return 0;
 }
 
+sub maxima_allowed_libraries {
+   return (
+      "absimp","affine","atensor","atrig1","augmented_lagrangian","contrib_ode","ctensor","descriptive","diag",
+      "eigen","facexp","fft","fourie","functs","ggf","grobner","impdiff","ineq","interpol","itensor","lapack",
+      "lbfgs","lindstedt","linearalgebra","lsquares","makeOrders","mnewton","mchrpl","ntrig","orthopoly",
+      "quadpack","rducon","romberg","scifac","simplex","solve_rec","sqdnst","stats","sterling","sym","units",
+      "vect","zeilberger");
+}
+
+sub maxima_is_allowed_library {
+    my ($library)=@_;
+    foreach my $allowed_library (&maxima_allowed_libraries()) {
+       if ($library eq $allowed_library) { return 1; }
+    }
+    return 0;
+}
+
 sub runscript {
-    my ($socket,$fullscript)=@_;
+    my ($socket,$fullscript,$libraries)=@_;
     if (&blacklisted($fullscript)) { return 'Error: blacklisted'; }
     my $reply;
     $fullscript=~s/[\n\r\l]//gs;
+    if ($libraries) {
+       foreach my $library (split(/\s*\,\s*/,$libraries)) {
+          unless ($library=~/\w/) { next; }
+          if (&maxima_is_allowed_library($library)) {
+              $reply=&maximareply($socket,'load('.$library.')$'."\n");
+              if ($reply=~/^Error\:/) { return $reply; }
+          } else { 
+             return 'Error: blacklisted'; 
+          }
+       }
+    }
     foreach my $line (split(/\;/s,$fullscript)) {
 	if ($line=~/\w/) { $reply=&maximareply($socket,$line.";\n"); }
 	if ($reply=~/^Error\:/) { return $reply; }
@@ -91,7 +119,7 @@ sub maxima_cas_formula_fix {
 }
 
 sub maxima_run {
-    my ($script,$submission,$argument) = @_;
+    my ($script,$submission,$argument,$libraries) = @_;
     my $socket=&connect();
     my @submissionarray=split(/\s*\,\s*/,$submission);
     for (my $i=0;$i<=$#submissionarray;$i++) {
@@ -105,7 +133,7 @@ sub maxima_run {
         my $fixedargument=&maxima_cas_formula_fix($argumentarray[$i]);
         $script=~s/LONCAPALIST\[$n\]/$fixedargument/gs;
     }
-    my $reply=&runscript($socket,$script);
+    my $reply=&runscript($socket,$script,$libraries);
     &disconnect($socket);
     if ($reply=~/^\s*true\s*$/i) { return 'EXACT_ANS'; }
     if ($reply=~/^\s*false\s*$/i) { return 'INCORRECT'; } 
@@ -113,9 +141,9 @@ sub maxima_run {
 }
 
 sub maxima_eval {
-    my ($script) = @_;
+    my ($script,$libraries) = @_;
     my $socket=&connect();
-    my $reply=&runscript($socket,$script);
+    my $reply=&runscript($socket,$script,$libraries);
     &disconnect($socket);
     return $reply;
 }
@@ -139,6 +167,8 @@ sub maxima_check {
     # integer to string mappings come from capaParser.h
     # 1 maps to 'EXACT_ANS'
     if ($reply eq 'true') { return 1; }
+    # 11 maps to 'BAD_FORMULA'
+    if ($reply=~/^Error\:/) { return 11; }
     # 7 maps to 'INCORRECT'
     return 7;
 }
