@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.149 2008/02/01 22:05:45 raeburn Exp $
+# $Id: optionresponse.pm,v 1.150 2008/06/23 11:27:44 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -503,7 +503,7 @@ sub displayfoils {
 
 sub optionlist_correction {
     my ($TeXlayout,@options) = @_;
-    my $texoptionlist='\\item [] Choices: ';
+    my $texoptionlist='\\item [] '.&mt('Choices:').' ';
     if ($TeXlayout eq 'vertical') {$texoptionlist='\\item []';}
     if (scalar(@options) > 0) {
 	foreach my $option (@options) {
