@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # mutliple choice style responses
 #
-# $Id: radiobuttonresponse.pm,v 1.131 2008/02/01 22:05:45 raeburn Exp $
+# $Id: radiobuttonresponse.pm,v 1.133 2008/03/22 00:36:57 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -567,9 +567,13 @@ sub displayfoils {
 		$result.='\item \vskip -2 mm  ';
 	    }
 	    if ($Apache::response::foilgroup{$name.'.value'} eq 'true') { 
-		if ($target ne 'tex') { $result.='Correct:<b>'; } else { $result.='Correct: \textbf{';}
+		if ($target ne 'tex') {
+                    $result.=&mt('Correct:').'<b>';
+                } else {
+                    $result.=&mt('Correct:').' \textbf{';
+                }
 	    } else {
-		$result.='Incorrect:';
+		$result.=&mt('Incorrect:');
 	    }
 	    if ($target eq 'web') { $result.="<label>"; }
 	    $result.=$Apache::response::foilgroup{$name.'.text'};
