@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.423 2008/06/11 13:52:35 www Exp $
+# $Id: structuretags.pm,v 1.425 2008/07/28 05:26:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -148,6 +148,10 @@ sub page_start {
 
     $extra_head .= &homework_js();
 
+    unless ($env{'environment.wysiwygeditor'} eq 'on') {
+        $extra_head .= &Apache::lonhtmlcommon::dragmath_js();
+    }
+
     my %body_args;
     if (defined($found{'html'})) {
 	$body_args{'skip_phases'}{'head'}=1;
@@ -1870,6 +1874,7 @@ sub end_startouttext {
     my $text='';
 
     if ($target eq 'edit') {
+	my $areaid = 'homework_edit_'.$Apache::lonxml::curdepth;
 	$text=&Apache::lonxml::get_all_text("endouttext",$parser,$style);
 	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>
 <td>".&mt('Delete:').
@@ -1877,7 +1882,13 @@ sub end_startouttext {
 		 ."</td>
 <td>".
                  &Apache::edit::insertlist($target,$token).
-		 '</td><td align="right" valign="top">' .
+		 '</td>';
+        unless ($env{'environment.wysiwygeditor'} eq 'on') {
+            $result.='<td align="left">'
+                     .&Apache::lonhtmlcommon::dragmath_button($areaid,1)
+                     .'</td>';
+        }
+	$result.='<td align="right" valign="top">' .
 		 &Apache::loncommon::helpLatexCheatsheet().
 		 &Apache::edit::end_row().
                  &Apache::edit::start_spanning_row()."\n".
