@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # routines for clone a course
 #
-# $Id: lonclonecourse.pm,v 1.4 2008/01/18 17:51:18 raeburn Exp $
+# $Id: lonclonecourse.pm,v 1.6 2008/01/22 22:37:18 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -141,7 +141,8 @@ sub copydb {
 # ========================================================== Copy resourcesdata
 
 sub copyresourcedb {
-    my ($origcrsid,$newcrsid)=@_;
+    my ($origcrsid,$newcrsid,$date_mode,$date_shift)=@_;
+    my $delta=$date_shift*60*60*24;
     my %origcrsdata=&Apache::lonnet::coursedescription($origcrsid);
     my %newcrsdata= &Apache::lonnet::coursedescription($newcrsid);
     my %data=&Apache::lonnet::dump
@@ -161,46 +162,43 @@ sub copyresourcedb {
 
 	$startdate = $start{'default_enrollment_start_date'};
     }
-    my $today=time;
-    my $delta=0;
-    if ($startdate) {
-	my $oneday=60*60*24;
-	$delta=$today-$startdate;
-	$delta=int($delta/$oneday)*$oneday;
-    }
 # ugly retro fix for broken version of types
-    foreach (keys %data) {
-	if ($_=~/\wtype$/) {
-	    my $newkey=$_;
+    foreach my $key (keys %data) {
+	if ($key=~/\wtype$/) {
+	    my $newkey=$key;
 	    $newkey=~s/type$/\.type/;
-	    $data{$newkey}=$data{$_};
-	    delete $data{$_};
+	    $data{$newkey}=$data{$key};
+	    delete $data{$key};
 	}
     }
 # adjust symbs
     my $pattern='uploaded/'.$origcrsdata{'domain'}.'/'.$origcrsdata{'num'}.'/';
     my $new=    'uploaded/'. $newcrsdata{'domain'}.'/'. $newcrsdata{'num'}.'/';
-    foreach (keys %data) {
-	if ($_=~/\Q$pattern\E/) {
-	    my $newkey=$_;
+    foreach my $key (keys %data) {
+	if ($key=~/\Q$pattern\E/) {
+	    my $newkey=$key;
 	    $newkey=~s/\Q$pattern\E/$new/;
-	    $data{$newkey}=$data{$_};
-	    delete $data{$_};
+	    $data{$newkey}=$data{$key};
+	    delete $data{$key};
 	}
     }
-# adjust dates
-    foreach (keys %data) {
-	my $thiskey=$_;
+#  transfer hash
+    foreach my $key (keys %data) {
+	my $thiskey=$key;
 	$thiskey=~s/^$origcrsid/$newcrsid/;
-	$newdata{$thiskey}=$data{$_};
-	if ($data{$_.'.type'}=~/^date_(start|end)$/) {
-	    if ($delta > 0) {
-		$newdata{$thiskey}=$newdata{$thiskey}+$delta;
-	    } else {
-		# no delta, it's unlikely we want the old dates and times
-		delete($newdata{$thiskey});
-		delete($newdata{$thiskey.'.type'});
-	    }
+	$newdata{$thiskey}=$data{$key};
+# date_mode empty or "preserve": transfer dates one-to-one
+# date_mode "shift": shift dates by date_shift days
+# date_mode other: do not transfer dates
+        if (($date_mode) && ($date_mode ne 'preserve')) {
+	    if ($data{$key.'.type'}=~/^date_(start|end)$/) {
+	       if ($date_mode eq 'shift') {
+		  $newdata{$thiskey}=$newdata{$thiskey}+$delta;
+	       } else {
+		  delete($newdata{$thiskey});
+		  delete($newdata{$thiskey.'.type'});
+	       }
+            }
 	}
     }
     return &Apache::lonnet::put
@@ -237,10 +235,10 @@ sub copydbfiles {
 # ======================================================= Copy all course files
 
 sub copycoursefiles {
-    my ($origcrsid,$newcrsid)=@_;
+    my ($origcrsid,$newcrsid,$date_mode,$date_shift)=@_;
     &copyuserfiles($origcrsid,$newcrsid);
     &copydbfiles($origcrsid,$newcrsid);
-    &copyresourcedb($origcrsid,$newcrsid);
+    &copyresourcedb($origcrsid,$newcrsid,$date_mode,$date_shift);
 }
 
 1;
