@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.175 2008/06/01 00:04:39 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.177 2008/07/28 05:25:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,6 +62,57 @@ use Apache::lonlocal;
 use Apache::lonnet;
 use LONCAPA;
 
+
+##############################################
+##############################################
+
+=pod
+
+=item dragmath_button
+
+Creates a button that launches a dragmath popup-window, in which an 
+expression can be edited and pasted as LaTeX into a specified textarea. 
+
+  textarea - Name of the textarea to edit.
+  helpicon - If true, show a help icon to the right of the button.
+
+=cut
+
+sub dragmath_button {
+    my ($textarea,$helpicon) = @_;
+    my $help_text; 
+    if ($helpicon) {
+        $help_text = &Apache::loncommon::help_open_topic('Authoring_Math_Editor');
+    }
+    return <<ENDDRAGMATH;
+                <input type="button" value="Edit Math", onclick="javascript:mathedit('$textarea',document)" />$help_text
+ENDDRAGMATH
+}
+
+##############################################
+
+=pod
+
+=item dragmath_js
+
+Javascript used to open pop-up window containing dragmath applet which 
+can be used to paste LaTeX into a textarea.
+ 
+=cut
+
+sub dragmath_js {
+    return <<ENDDRAGMATHJS;
+                <script type="text/javascript">
+                  function mathedit(textarea, doc) {
+                     targetEntry = textarea;
+                     targetDoc   = doc;
+                     newwin  = window.open("/adm/dragmath/applet/EditMathPopup.html","","width=565,height=500,resizable");
+                  }
+                </script>
+
+ENDDRAGMATHJS
+}
+
 ##############################################
 ##############################################
 
@@ -1922,6 +1973,8 @@ END
     return $scripttag;
 }
 
+
+
 1;
 
 __END__
