@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.124 2008/06/10 14:49:07 www Exp $
+# $Id: lonpreferences.pm,v 1.125 2008/07/18 12:36:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1929,7 +1929,8 @@ sub handler {
                             text => 'Register Clicker'},
                       printmenu => 'yes',
                       }));
-   if ($env{'user.adv'}) {
+    my %author_roles = &Apache::lonnet::get_my_roles($user,$domain,'userroles','',['au']);
+    if (keys(%author_roles) > 0) {
       push (@Options,({ action   => 'changedomcoord',
                         linktext => 'Restrict Domain Coordinator Access',
                         href     => '/adm/preferences',
