@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # User Authentication Module
 #
-# $Id: lonremote.pm,v 1.23 2008/01/20 01:12:56 www Exp $
+# $Id: lonremote.pm,v 1.24 2008/03/12 02:45:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -39,7 +39,7 @@ use Apache::lonlocal;
 sub launchremote {
     my ($r,$lowerurl)=@_;
     &Apache::lonnet::put('environment',{'remote' => 'on'});
-    &Apache::lonnet::appenv('environment.remote' => 'on');
+    &Apache::lonnet::appenv({'environment.remote' => 'on'});
 # -------------------------------------------------------- Menu script and info
     my $windowinfo=&Apache::lonmenu::open($env{'browser.os'});
     my $startupremote=&Apache::lonmenu::startupremote($lowerurl);
@@ -82,7 +82,7 @@ $message
 $end_page
 ENDCOLLAPSE
    &Apache::lonnet::put('environment',{'remote' => 'off'});
-   &Apache::lonnet::appenv('environment.remote' => 'off');
+   &Apache::lonnet::appenv({'environment.remote' => 'off'});
 }
 
 sub handler {
