@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # lonselstudent.pm : Reusable subs for student selection.
 #
-# $Id: lonselstudent.pm,v 1.11 2007/11/01 20:04:17 albertel Exp $
+# $Id: lonselstudent.pm,v 1.12 2008/06/06 19:12:59 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -331,7 +331,7 @@ SCRIPT
 	    $result .= '<option name="'.$sec.'">'.$sec.'</option>'."\n";
 	}
 	$result .= '</td><td valign="top">';
-	$result .= '<input type="button" name="'.$formprefix.'.select" value="'.'Select" onclick='
+	$result .= '<input type="button" name="'.$formprefix.'.select" value="'.&mt('Select').'" onclick='
 	    ."'selectSections(\"$formprefix.chosensections\", \"$formprefix\")'".' /></td>';
 	$result .= '<td valign="top"><input type="button" name="'.$formprefix
 	    .'.unselect" value="'.&mt('Unselect').'"  onclick='.
