@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.63 2008/01/16 17:13:57 bisitz Exp $
+# $Id: lonsyllabus.pm,v 1.66 2008/07/17 12:01:46 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -110,14 +110,58 @@ sub handler {
 # ----------------------------------------------------------------- Make header 
     if ($target ne 'tex') {
 	my $rss_link = &Apache::lonrss::rss_link($cnum,$cdom);
+        my $js;
+        if ($env{'form.backto'} eq 'coursecatalog') {
+            $js .= <<"ENDSCRIPT";
+
+<script type="text/javascript">
+function ToCatalog(caller) {
+    numidx = getIndexByName('coursenum');
+    if (numidx > -1) {
+        if (caller != 'details') {
+            document.backtocat.elements[numidx].value = '';
+        }
+    }
+    document.backtocat.submit();
+}
+
+function getIndexByName(item) {
+    for (var i=0;i<document.backtocat.elements.length;i++) {
+        if (document.backtocat.elements[i].name == item) {
+            return i;
+        }
+    }
+    return -1;
+}
+
+</script>
+
+ENDSCRIPT
+        }
 	my $start_page = 
-	    &Apache::loncommon::start_page("Syllabus", $rss_link,
+	    &Apache::loncommon::start_page("Syllabus", $rss_link.$js,
 					   {'function'       => $forcestudent,
 					    'domain'         => $cdom,
 					    'force_register' =>
 						$env{'form.register'},});
 
-	$r->print($start_page.'<h1>'.$courseenv{'description'}.'</h1><h3>'.
+	$r->print($start_page);
+        if ($env{'form.backto'} eq 'coursecatalog') {
+            &Apache::lonhtmlcommon::clear_breadcrumbs();
+            &Apache::lonhtmlcommon::add_breadcrumb
+             ({href=>"javascript:ToCatalog()",
+               text=>"Course Catalog"});
+            if ($env{'form.coursenum'} ne '') {
+                &Apache::lonhtmlcommon::add_breadcrumb
+                  ({href=>"javascript:ToCatalog('details')",
+                   text=>"Course details"});
+            }
+            &Apache::lonhtmlcommon::add_breadcrumb
+              ({href=>$r->uri,
+               text=>"Course syllabus"});
+            $r->print(&Apache::lonhtmlcommon::breadcrumbs());
+        }
+        $r->print('<h1>'.$courseenv{'description'}.'</h1><h3>'.
 		  &Apache::lonnet::domain($cdom,'description').'</h3>');
     } else {
 	$r->print('\noindent{\large\textbf{'.$courseenv{'description'}.'}}\\\\\\\\\textbf{'.
@@ -149,9 +193,14 @@ sub handler {
         foreach (split(/\,/,$coursepersonnel{$element})) {
 	    my ($puname,$pudom)=split(/\:/,$_);
 	    if ($target ne 'tex') {
-		$r->print(' '.&Apache::loncommon::aboutmewrapper(
-                              &Apache::loncommon::plainname($puname,
-                              $pudom),$puname,$pudom));
+                my $courseperson = &Apache::loncommon::plainname($puname,$pudom);
+                if (($env{'user.name'} eq '') || ($env{'user.name'} eq 'public') ||
+                    ($env{'user.domain'} eq '') || ($env{'user.domain'} eq 'public')) {
+		    $r->print(' '.$courseperson);
+                } else {
+                    $r->print(' '.&Apache::loncommon::aboutmewrapper($courseperson),
+                              $puname,$pudom);
+                }
 	    } else {
 		$r->print(' '.&Apache::loncommon::plainname($puname,
                               $pudom).' ');
@@ -342,6 +391,11 @@ sub handler {
 	if ($target ne 'tex') {$r->print('</p>');}
     }
     if ($target ne 'tex') {
+        if ($env{'form.backto'} eq 'coursecatalog') {
+            $r->print('<form name="backtocat" method="post" action="/adm/coursecatalog">'.
+                      &Apache::lonhtmlcommon::echo_form_input(['backto','courseid']).
+                      '</form>');
+        }
 	$r->print(&Apache::loncommon::end_page());
     } else {
 	$r->print('\end{document}');
