@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.78 2008/06/19 15:51:39 bisitz Exp $
+# $Id: lonwhatsnew.pm,v 1.79 2008/07/09 15:16:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1220,8 +1220,8 @@ sub getactivated {
             if (ref($changes{$chg}) eq 'HASH') {
                 my $timestamp = $changes{$chg}{'exe_time'};
                 if ($timestamp) {
-                    if ($rolechgtime > -1) {
-                        if ($now - $rolechgtime < $timestamp) {
+                    if ($rolechgtime > 0) {
+                        if ($timestamp < $rolechgtime) {
                             last;
                         }
                     }
