@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Allow users to self-enroll in a course
 #
-# $Id: selfenroll.pm,v 1.7 2008/07/08 01:55:52 raeburn Exp $
+# $Id: selfenroll.pm,v 1.13 2008/07/17 20:08:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,7 @@ use Apache::Constants qw(:common);
 use Apache::lonnet;
 use Apache::loncommon;
 use Apache::lonlocal;
+use Apache::createaccount;
 use LONCAPA qw(:DEFAULT :match);
 
 sub handler {
@@ -44,34 +45,41 @@ sub handler {
     }
     my $handle = &Apache::lonnet::check_for_valid_session($r);
     my $lonidsdir=$r->dir_config('lonIDsDir');
+    my $lonhost = $r->dir_config('lonHostID');
     if ($handle ne '') {
         &Apache::lonnet::transfer_profile_to_env($lonidsdir,$handle);
     }
     &Apache::lonacc::get_posted_cgi($r);
     &Apache::lonlocal::get_language_handle($r);
-    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['cid']);
-    my ($coursechk,$cid) = &validate_course_id($env{'form.cid'});
-    my $start_page =
-        &Apache::loncommon::start_page('Self-enroll in a LON-CAPA course','',
-                                       {'no_inline_link'   => 1,});
-    $r->print($start_page);
-    &Apache::lonhtmlcommon::clear_breadcrumbs();
-    &Apache::lonhtmlcommon::add_breadcrumb
-    ({href=>"/adm/selfenroll?cid=$cid",
-      text=>"Self-enroll"});
-    $r->print(&Apache::lonhtmlcommon::breadcrumbs('Self-enroll in course'));
+    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['courseid']);
+    my $js = &Apache::createaccount::catreturn_js();
+    my $desc;
+    my ($coursechk,$courseid) = &validate_course_id($env{'form.courseid'});
     if ($coursechk ne 'ok') {
-        $r->print(&mt('Invalid domain or course number'));
-        $r->print(&Apache::loncommon::end_page());
+        &page_header($r,$courseid,$js);
+        $r->print('<h3>'.&mt('Self-enrollment error').'</h3>'.
+                  '<span class="LC_error">'.
+                  &mt('Invalid domain or course number').'</span>');
+        &page_footer($r);
         return OK;
     }
-    my ($cdom,$cnum,$canenroll,$selfenroll_types,$selfenroll_registered,
-        @cancreate,$knownuser,$selfenroll_access_start,$selfenroll_access_end,
-        $selfenroll_section,%curr_role,%coursehash);
     my $now = time;
-    %coursehash = &Apache::lonnet::coursedescription($cid);
-    $cdom = $coursehash{'domain'};
-    $cnum = $coursehash{'num'};
+    if ($env{'form.phase'} eq 'login') {
+        $js .= "\n".&Apache::createaccount::javascript_setforms($now);
+    }
+    my %coursehash = &Apache::lonnet::coursedescription($courseid);
+    my $cdom = $coursehash{'domain'};
+    my $cnum = $coursehash{'num'};
+    my $desc = $coursehash{'description'};
+    &page_header($r,$courseid,$js,$desc);
+    my $include = $r->dir_config('lonIncludes');
+    if ($env{'form.phase'} eq 'login') {
+        my $jsh=Apache::File->new($include."/londes.js");
+        $r->print(<$jsh>);
+    }
+    my ($canenroll,$selfenroll_types,$selfenroll_registered,@cancreate,
+        $knownuser,$selfenroll_access_start,$selfenroll_access_end,
+        $selfenroll_section,$selfenroll_future,%curr_role,$cdomdesc);
     $selfenroll_types = $coursehash{'internal.selfenroll_types'};
     $selfenroll_registered =  $coursehash{'internal.selfenroll_registered'};
     $selfenroll_section = $coursehash{'internal.selfenroll_section'};
@@ -80,14 +88,55 @@ sub handler {
     if ($selfenroll_types ne '') {
         my $start = $coursehash{'internal.selfenroll_start_date'};
         my $end = $coursehash{'internal.selfenroll_end_date'};
-        if (($start > 0 && $start < $now) && ($end > 0 && $end > $now)) {
+        if (($start > 0 && $start < $now) && (($end == 0) || ($end > 0 && $end > $now))) {
             $canenroll = 1;
+        } elsif (($end == 0) || ($end > 0 && $end > $now)) {
+            if ($start > $now) {
+                $selfenroll_future = &Apache::lonlocal::locallocaltime($start);
+            }
         }
     }
-    if (!$canenroll) {
-        $r->print(&mt('Self-enrollment is not currently available for this course.').'<br /><br />');
-    }
     $knownuser = &user_is_known();
+    if (!$canenroll) {
+        $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3><span class="LC_warning">'.
+                  &mt('Self-enrollment is not currently available for this course.').
+                  '</span><br /><br />');
+        if ($selfenroll_types ne '') {
+            if ($selfenroll_future ne '') {
+                if ($selfenroll_types eq '*') {
+                    $r->print(&mt('Self-enrollment will become available starting [_1], and will be available to all LON-CAPA users.',$selfenroll_future).'<br />');
+                } else {
+                    my ($enrolltypes,$longtypes,$alldoms);
+                    if ($knownuser) {
+                        &get_selfenroll_filters($selfenroll_types,$env{'user.domain'});
+                        my $domdesc = &Apache::lonnet::domain($env{'user.domain'},'description');
+                        if (ref($enrolltypes) eq 'HASH') {
+                            if (ref($enrolltypes->{$env{'user.domain'}}) eq 'ARRAY') {
+                                if (grep(/^any$/,@{$enrolltypes->{$env{'user.domain'}}})) {
+                                    $r->print(&mt('Self-enrollment will become available starting [_1], and will be available to all LON-CAPA users at your institution ([_2]).',
+                                              $selfenroll_future,$domdesc).'<br />');
+
+                                } else {
+                                    if (&user_can_selfenroll($env{'user.domain'},
+                                                        $env{'user.name'},
+                                                        $enrolltypes->{$env{'user.domain'}})) {
+                                        $r->print(&mt('Self-enrollment will become available starting [_1]; please enroll at that time.',$selfenroll_future)); 
+                                    } else {
+                                        $r->print(&mt('Although self-enrollment will become available starting [_1], you are ineligible for enrollment.',$selfenroll_future).'<br />');
+                                        $r->print(&print_selfenroll_types($longtypes,$env{'user.domain'}));
+                                    }
+                                }
+                            }
+                        } 
+                    } else {
+                        $r->print(&mt('Self-enrollment will become available starting [_1].',
+                                      $selfenroll_future).'<br />');
+                        $r->print(&print_selfenroll_types($longtypes));
+                    }
+                }
+            } 
+        }
+    }
     if ($knownuser) {
         foreach my $key (keys(%env)) {
             if ($key =~ m-^user\.role\.st\./$cdom/$cnum/?(\w*)$-) {
@@ -119,54 +168,64 @@ sub handler {
         if (keys(%curr_role)) {
             $r->print(&has_role(%curr_role));
         }
-        $r->print(&Apache::loncommon::end_page());
+        &page_footer($r);
         return OK;
     }
     @cancreate = &can_create($cdom);
-    my ($login_path,$firsturl,$create_path,$sso_url,$missing_formitem);
+    my ($form,$login_path,$firsturl,$create_path,$sso_url,$missing_formitem);
+    $form = 'logmein';
     $login_path = '/adm/login';
-    $firsturl= '/adm/selfenroll?cid='.$cid;
+    $firsturl= '/adm/selfenroll?courseid='.$courseid;
     $create_path = '/adm/createaccount';
     $sso_url = $r->dir_config('lonSSOReloginServer');
     if ($sso_url eq '') {
         $sso_url = $login_path;
     }
-    my $missing_formitem = &mt('The link to the requested page could not be followed.')."\\n".&mt('The placeholder for the courseID is absent.');
+    $missing_formitem = &mt('The link to the requested page could not be followed.')."\\n".&mt('The placeholder for the courseID is absent.');
     if ($knownuser) {
         if (keys(%curr_role)) {
-            $r->print(&has_role(%curr_role));
+            $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3>'.
+                      '<span class="LC_warning">'.&has_role(%curr_role).'</span>');
+            &page_footer($r);
             return OK;
         }
         &process_self_enroll($r,$cdom,$cnum,$selfenroll_types,$selfenroll_registered,
                              $selfenroll_access_start,$selfenroll_access_end,
                              $selfenroll_section,$now);
+    } elsif ($env{'form.phase'} eq 'login') {
+        my $submit_text = &mt('Log in');
+        $r->print('<h3>'.&mt('Log-in to LON-CAPA').'</h3>');
+        my $udom = &Apache::lonnet::default_login_domain();
+        $r->print(&Apache::createaccount::login_box($now,$lonhost,$courseid,
+                                           $submit_text,$udom,'selfenroll'));
+        $r->print(&mt('You will be able to self-enroll in the course you selected ([_1]) after you have successfully logged in.','<b>'.$desc.'</b>'));
+        &page_footer($r);
+        return OK;
     } elsif (@cancreate > 0) {
         $r->print(<<END);
 <script type="text/javascript">
-function setPath(formaction,item,arg) {
-    document.forms.logmein.action = formaction;
-    var itemid = getIndexByName("setting");
-    if (itemid > -1) {
-        document.logmein.elements[itemid].name = item;
-        document.logmein.elements[itemid].value = arg;
-        document.logmein.submit();
-    } else {
-        alert("$missing_formitem");
+function setPath(formname,formaction,item,arg) {
+    var formidx = getFormByName(formname);
+    if (formidx > -1) {
+        if (formaction != '') {
+            document.forms[formidx].action = formaction;
+        }
+        var itemid = getIndexByName(formidx,'setting');
+        if (itemid > -1) {
+            document.forms[formidx].elements[itemid].name = item;
+            document.forms[formidx].elements[itemid].value = arg;
+            document.forms[formidx].submit();
+        } else {
+            alert("$missing_formitem");
+        }
     }
     return;
 }
 
-function getIndexByName(item) {
-    for (var i=0;i<document.logmein.elements.length;i++) {
-        if (document.logmein.elements[i].name == item) {
-            return i;
-        }
-    }
-    return -1;
-}
 </script>
 END
-        $r->print(&mt('You need to be logged into LON-CAPA to self-enroll in a course.').'<ul><li>'.&mt('If you have an account in LON-CAPA, [_1]log-in[_2].','<a href="javascript:setPath('."'$login_path','firsturl','$firsturl'".')">','</a>').'</li>');
+        $r->print('<h3>'.&mt('LON-CAPA account required').'</h3>'.
+                  &mt('You need to be logged into LON-CAPA to self-enroll in a course.').'<ul><li>'.&mt('If you have an account in LON-CAPA, [_1]log-in[_2].','<a href="javascript:setPath('."'$form','','phase','login'".')">','</a>').'</li>');
         if (@cancreate > 1) {
             $r->print('<li>'.&mt('Otherwise:').'<br />');
             my $count = 0;
@@ -176,11 +235,11 @@ END
                 }
                 if (grep(/^$type$/,@cancreate)) {
                     if ($type eq 'sso') {
-                        $r->print('&nbsp;&nbsp;'.&mt("if you have an institutional log-in, use your institution's [_1]single sign on page[_2] to log-in, then create an account",'<a href="javascript:setPath('."'$sso_url','firsturl','$firsturl'".')">','</a>'));
+                        $r->print('&nbsp;&nbsp;'.&mt("if you have an institutional log-in, use your institution's [_1]single sign on page[_2] to log-in, then create an account",'<a href="javascript:setPath('."'$form','$sso_url','firsturl','$firsturl'".')">','</a>'));
                     } elsif ($type eq 'login') {
-                        $r->print('&nbsp;&nbsp;'.&mt('if you have an institutional login, [_1]create an account[_2]','<a href="javascript:setPath('."'$create_path','courseid','$cid'".')">','</a>'));
+                        $r->print('&nbsp;&nbsp;'.&mt('if you have an institutional login, [_1]create an account[_2]','<a href="javascript:setPath('."'$form','$create_path','context','selfenroll_create'".')">','</a>'));
                     } elsif ($type eq 'email') {
-                        $r->print('&nbsp;&nbsp;'.&mt('you can use an e-mail address to [_1]create an account[_2]','<a href="javascript:setPath('."'$create_path','courseid','$cid'".')">','</a>'));
+                        $r->print('&nbsp;&nbsp;'.&mt('you can use an e-mail address to [_1]create an account[_2]','<a href="javascript:setPath('."'$form','$create_path','context','selfenroll_create'".')">','</a>'));
                     }
                     $count ++;
                 }
@@ -188,42 +247,68 @@ END
             $r->print('.<br />');
         } else {
             if ($cancreate[0] eq 'login') {
-                $r->print('<li>'.&mt('Otherwise, if you have an institutional login, [_1]create an account[_2].','<a href="javascript:setPath('."'$create_path','courseid','$cid'".')">','</a>'));
+                $r->print('<li>'.&mt('Otherwise, if you have an institutional login, [_1]create an account[_2].','<a href="javascript:setPath('."'$form','$create_path','context','selfenroll_create'".')">','</a>'));
             } elsif ($cancreate[0] eq 'email') {
-                $r->print('<li>'.&mt('Otherwise, you will use an e-mail address to [_1]create an account[_2].','<a href="javascript:setPath('."'$create_path','courseid','$cid'".')">','</a>'));
+                $r->print('<li>'.&mt('Otherwise, you will use an e-mail address to [_1]create an account[_2].','<a href="javascript:setPath('."'$form','$create_path','context','selfenroll_create'".')">','</a>'));
             } elsif ($cancreate[0] eq 'sso') {
-                $r->print('<li>'.&mt("Otherwise, use your institution's [_1]single sign on page[_2] to log-in, then create an account.",'<a href="javascript:setPath('."'$sso_url','firsturl','$firsturl'".')">','</a>'));
+                $r->print('<li>'.&mt("Otherwise, use your institution's [_1]single sign on page[_2] to log-in, then create an account.",'<a href="javascript:setPath('."'$form','$sso_url','firsturl','$firsturl'".')">','</a>'));
             }
         }
         if ($selfenroll_types eq '*') {
-            $r->print('<br />'.&mt('You will have an opportunity to self enroll in the course once the account has been created.').'</li></ul>');
+            $r->print('<br />'.&mt('You will be able to self enroll in this course once the account has been created.').'</li></ul>');
         } else {
             $r->print('</li></ul>');
             my ($enrolltypes,$longtypes,$alldoms) = 
-                &get_selfenroll_filters($selfenroll_types,$cdom);
-            $r->print(&print_selfenroll_types($longtypes,$cdom));
+                &get_selfenroll_filters($selfenroll_types);
+            $r->print(&print_selfenroll_types($longtypes));
         }
     } else {
-        $r->print(&mt('You must [_1]log-in[_2] to LON-CAPA with an existing account to be able to enroll in this course, as account creation is not permitted when self-enrolling.','<a href="'.$login_path.'">','</a>'));
+        my $cdomdesc = &Apache::lonnet::domain($cdom,'description');
+        $r->print('<h3>'.&mt('LON-CAPA account required').'</h3>');
+        $r->print(&mt('You must [_1]log-in[_2] to LON-CAPA with an existing account to be able to enroll in this course, as account creation at this institution ([_3]) is not permitted when self-enrolling.','<a href="'.$login_path.'">','</a>',$cdomdesc));
         if ($selfenroll_types ne '*') {
             my ($enrolltypes,$longtypes,$alldoms) =
                 &get_selfenroll_filters($selfenroll_types);
-            $r->print('<br /><br />'.&print_selfenroll_types($longtypes));
+            $r->print('<br />'.&print_selfenroll_types($longtypes));
         }
+        my $displayurl = &escape($firsturl);
+        $r->print(&mt('Submit a request to the LON-CAPA [_1]helpdesk[_2] for [_3] if you require assistance.','<a href="/adm/helpdesk?origurl='.$displayurl.'">','</a>',$cdomdesc));
     }
-    $r->print('<form name ="logmein" method="post" action="">'."\n".
+    $r->print("\n".'<form name="'.$form.'" method="post" action="">'."\n".
+              '<input type="hidden" name="courseid" value="'.$courseid.'" />'."\n".
               '<input type="hidden" name="setting" value=""/>'."\n".
-              '</form>'."\n".
-              &Apache::loncommon::end_page());
+              &Apache::lonhtmlcommon::echo_form_input(['backto','courseid','context','phase'])."\n".
+              '</form>'."\n");
+              &page_footer($r);
     return OK;
 }
 
+sub page_header {
+    my ($r,$courseid,$js,$desc) = @_;
+    my $start_page =
+        &Apache::loncommon::start_page('Self-enroll in a LON-CAPA course',$js,
+                                       {'no_inline_link'   => 1,});
+    $r->print($start_page);
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+    &Apache::createaccount::selfenroll_crumbs($r,$courseid,$desc);
+    $r->print(&Apache::lonhtmlcommon::breadcrumbs('Self-enroll in course'));
+    return;
+}
+
+sub page_footer {
+    my ($r) = @_;
+    $r->print('<form name="backupcrumbs" method="post" action="/adm/coursecatalog">'."\n".
+              &Apache::lonhtmlcommon::echo_form_input(['backto','courseid','phase','context']).
+              '</form>'.&Apache::loncommon::end_page());
+    return;
+}
+
 sub validate_course_id {
-    my ($cid) = @_;
-    my ($cdom,$cnum) = ($env{'form.cid'} =~ /^($match_domain)_($match_courseid)$/);
+    my ($courseid) = @_;
+    my ($cdom,$cnum) = ($env{'form.courseid'} =~ /^($match_domain)_($match_courseid)$/);
     if ($cdom ne '' && $cnum ne '') {
         if (&Apache::lonnet::is_course($cdom,$cnum)) {
-            return ('ok',$cid);
+            return ('ok',$courseid);
         }
     } 
     return;
@@ -264,9 +349,9 @@ sub has_role {
     my $output;
     if ($curr_role{'status'} eq 'active') {
           my $rolelink = &jump_to_role($curr_role{'role'});
-          $output = &mt('You currently have an active role (section: "[_1]") in this course.',$curr_role{'section'}).' '.$rolelink;
+          $output = &mt('You already have an active student role (section: "[_1]") in this course.',$curr_role{'section'}).'<br>'.$rolelink;
     } elsif ($curr_role{'status'} eq 'future') {
-        $output = &mt('You have a role (section: "[_1]") in this course which will become active [_2].',$curr_role{'section'},$curr_role{'start'});
+        $output = &mt('You have a student role (section: "[_1]") in this course which will become active [_2].',$curr_role{'section'},$curr_role{'start'});
     }
     return $output;
 }
@@ -276,30 +361,21 @@ sub process_self_enroll {
         $selfenroll_access_start,$selfenroll_access_end,$selfenroll_section,$now) = @_;
     my $udom = $env{'user.domain'};
     my $uname = $env{'user.name'};
-    my @info = ['inststatus'];
-    my %userhash = &Apache::lonnet::userenvironment($udom,$uname,@info);
-    my ($enrolltypes,$longtypes,$alldoms) = 
-        &get_selfenroll_filters($selfenroll_types,$udom);
-    my @inststatuses;
-    if ($userhash{'inststatus'} eq '') {
-        push(@inststatuses,'other'); 
-    } else {
-        my @esc_statuses = split(/:/,$userhash{'inststatus'});
-        @inststatuses = map { &unescape($_); } (@esc_statuses);
-    }
     my $selfenroll = 0;
-    if ($alldoms) {
+    my ($enrolltypes,$longtypes,$alldoms);
+    if ($selfenroll_types eq '*') {
         $selfenroll = 1;
-    } elsif (ref($enrolltypes) eq 'HASH') {
-        if (ref($enrolltypes->{$udom}) eq 'ARRAY') {
-            if (grep(/^any$/,@{$enrolltypes->{$udom}})) {
-                $selfenroll = 1;
-            } else {
-                foreach my $type (@inststatuses) {
-                    if (grep(/^\Q$type\E$/,@{$enrolltypes->{$udom}})) {
-                        $selfenroll = 1;
-                        last;
-                    }
+    } else {
+        ($enrolltypes,$longtypes,$alldoms) =
+            &get_selfenroll_filters($selfenroll_types,$udom);
+        if ($alldoms) {
+            $selfenroll = 1;
+        } elsif (ref($enrolltypes) eq 'HASH') {
+            if (ref($enrolltypes->{$udom}) eq 'ARRAY') {
+                if (grep(/^any$/,@{$enrolltypes->{$udom}})) {
+                    $selfenroll = 1;
+                } else {
+                    $selfenroll = &user_can_selfenroll($udom,$uname,$enrolltypes->{$udom});
                 }
             }
         }
@@ -313,7 +389,7 @@ sub process_self_enroll {
             my ($registered,$instsec,$message) = &check_registered($cdom,$cnum);
             $usec = $instsec;
             if (!$registered) {
-                $r->print(&mt('Self-enrollment is restricted to students officially registered for this course.').'<br />');
+                $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3>'.&mt('Self-enrollment is restricted to students officially registered for this course.').'<br />');
                 if ($message) {
                     $r->print($message);
                 } else {
@@ -339,7 +415,8 @@ sub process_self_enroll {
                                                 $area);
             &Apache::lonnet::set_userprivs(\%userroles,\%newrole,%newgroups);
             $userroles{'user.role.'.$spec} = $selfenroll_access_start.'.'.$selfenroll_access_end;
-            &Apache::lonnet::appenv(\%userroles,[$role]);
+            &Apache::lonnet::appenv(\%userroles,[$role,'cm']);
+            $r->print('<h3>'.&mt('Enrollment process complete').'</h3>');
             if ($selfenroll_access_end && $selfenroll_access_end <= $now) {
                 $r->print(&mt('The end date for access to this course for users who self-enroll has passed.').'<br />'.&mt('Consequently, although a new role was created for you in the course, it is an inactive role which does not provide access to the course.'));
             } else {
@@ -359,18 +436,41 @@ sub process_self_enroll {
                 }
             }
         } else {
-            $r->print(&mt('Self-enrollment in this course failed.'));
+            $r->print('<h3>'.&mt('Enrollment incomplete').'</h3>'.
+                      &mt('Self-enrollment in this course failed.'));
             if ($enrollresult ne '') {
                 $r->print('<span class="LC_error">'.$enrollresult.'</span>');
             }
         }
     } else {
-        $r->print(&mt('You are not permitted to enroll yourself in this course.').'<br />');
+        $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3>'.
+                  &mt('You are not permitted to enroll yourself in this course.').'<br />');
         $r->print(&print_selfenroll_types($longtypes));
     }
     return;
 }
 
+sub user_can_selfenroll {
+    my ($udom,$uname,$domenrolltypes) = @_;
+    my $selfenroll = 0;
+    my %userhash = &Apache::lonnet::userenvironment($udom,$uname,'inststatus');
+    my @inststatuses;
+    if ($userhash{'inststatus'} eq '') {
+        push(@inststatuses,'other');
+    } else {
+        @inststatuses = split(':',$userhash{'inststatus'});
+    }
+    foreach my $type (@inststatuses) {
+        if (ref($domenrolltypes) eq 'ARRAY') {
+            if (grep(/^\Q$type\E$/,@{$domenrolltypes})) {
+                $selfenroll = 1;
+                last;
+            }
+        }
+    }
+    return $selfenroll;
+}
+
 sub jump_to_role {
     my ($role) = @_;
     my $output = <<"END";
@@ -383,7 +483,7 @@ function SelectRole() {
 END
     $output .= '<a href="javascript:SelectRole()">'."\n". 
                &mt('Enter course now').'</a>'."\n".
-               '<form name="rolechoice" action="/adm/roles">'."\n".
+               '<form name="rolechoice" action="/adm/roles" method="post">'."\n".
                '<input type="hidden" name="selectrole" value="" />'."\n".
                '<input type="hidden" name="'.$role.'" value="1" />'."\n".
                '</form>';
@@ -406,13 +506,34 @@ sub get_selfenroll_filters {
         if ($selfdom =~ /^$match_domain$/) {
             if (&Apache::lonnet::domain($selfdom) ne '') {
                 my @types = split(/,/,$type_str);
+                my @unesc_types = map { &unescape($_); } @types;
                 my ($othertitle,$usertypes,$types) =
                     &Apache::loncommon::sorted_inst_types($selfdom);
                 if (ref($usertypes) eq 'HASH') {
-                    $usertypes->{'any'} = &mt('any');
-                    $usertypes->{'other'} = &mt('other');
-                    @{$enrolltypes{$selfdom}} = @types;
-                    @{$longtypes{$selfdom}} = map {$usertypes->{$_}} @types;
+                    my $anytype = 1;
+                    foreach my $key (keys(%{$usertypes})) {
+                        if (!grep(/^\Q$key\E$/,@unesc_types)) {
+                            $anytype = 0;
+                            last;
+                        }
+                    }
+                    if ($anytype) {
+                        if (!(grep(/^other$/,@types))) {
+                            $anytype = 0;
+                        }
+                    }
+                    $usertypes->{'any'} = &mt('Any users');
+                    $usertypes->{'other'} = &mt('Others');
+                    my @showtypes;
+                    if ($anytype) {
+                        @{$enrolltypes{$selfdom}} = ('any');
+                        @showtypes =  ('any');
+                    } else {
+                        @{$enrolltypes{$selfdom}} = @types;
+                        @showtypes = @unesc_types;
+                    }
+                    @{$longtypes{$selfdom}} = 
+                        map {$usertypes->{$_}} @showtypes;
                 }
             }
         }
@@ -424,25 +545,27 @@ sub print_selfenroll_types {
     my ($longtypes,$domain) = @_;
     my $output;
     if (ref($longtypes) eq 'HASH') {
-        if (keys(%{$longtypes}) > 0) {
-            if ($domain ne '') {
-                if (ref($longtypes->{$domain}) eq 'ARRAY') {
-                    if (grep(/^any$/,@{$longtypes->{$domain}})) {
-                        $output = &mt('Self-enrollment in this course is only available to users in domain "[_1]".',$domain);
-                    } else {
-                        my $status_str = join(', ',@{$longtypes->{$domain}});
-                        $output = &mt('Self-enrollment in this course is only available to users in domain "[_1]" who have the following status: "[_2]".',$domain,$status_str);
-                    }
+        if ($domain ne '') {
+            my $domdesc = &Apache::lonnet::domain($domain,'description');
+            if (ref($longtypes->{$domain}) eq 'ARRAY') {
+                if (grep(/^any$/,@{$longtypes->{$domain}})) {
+                    $output = &mt('Self-enrollment in this course is available to any user affiliated with [_1].',$domdesc);
+                } else {
+                    my $status_str = join(', ',@{$longtypes->{$domain}});
+                    $output = &mt('Self-enrollment in this course is only available to users affiliated with [_1] who have the following status: "[_2]".',$domdesc,$status_str);
                 }
             } else {
-                $output = &mt('Self-enrollment in this course is only available to users in the following domains (with the following status):').' <ul>';
-                foreach my $selfdom (sort(keys(%{$longtypes}))) {
-                    if (ref($longtypes->{$selfdom}) eq 'ARRAY') {
-                        $output .= '<li>'.$selfdom.': '.join(', ',@{$longtypes->{$selfdom}}).'</li>';
-                    }
-                }
-                $output .= '</ul>';
+                $output = &mt('Self-enrollment is not currently available for this course for users affiliated with [_1].',$domdesc);
             }
+        } elsif (keys(%{$longtypes}) > 0) {
+            $output = &mt('Self-enrollment in this course is only available to users affiliated with the following institutions, and who have the required status:').' <ul>'."\n";
+            foreach my $selfdom (sort(keys(%{$longtypes}))) {
+                my $selfdomdesc = &Apache::lonnet::domain($selfdom,'description');
+                if (ref($longtypes->{$selfdom}) eq 'ARRAY') {
+                    $output .= '<li>'.$selfdomdesc.': '.join(', ',@{$longtypes->{$selfdom}}).'</li>'."\n";
+                }
+            }
+            $output .= '</ul>'."\n";
         } else {
             $output = &mt('Self-enrollment is not currently available for this course.');
         }
