@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.105 2007/11/02 19:24:44 albertel Exp $
+# $Id: lonpubdir.pm,v 1.108 2008/01/17 04:50:57 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -105,7 +105,7 @@ sub handler {
   my $numres = 0;
   
   # Start off the directory table.
-  $r->print('<h3>Directory Contents:</h3>');
+  $r->print('<h3>'.&mt('Directory Contents:').'</h3>');
   $r->print('<table id="LC_browser"><tr>'.
             '<th>'.&mt('Type').'</th>'.
             '<th>'.&mt('Actions').'</th>'.
@@ -197,7 +197,7 @@ sub startpage {
     my $formaction='/priv/'.$uname.$thisdisfn.'/';
     $formaction=~s|/+|/|g;
     my $pagetitle .= &Apache::loncommon::help_open_menu('','',3,'Authoring').
-        '<font face="Arial, Helvetica, sans-serif" size="+1"><b>Construction Space</b>:</font>&nbsp;'.
+        '<font face="Arial, Helvetica, sans-serif" size="+1"><b>'.&mt('Construction Space').'</b>:</font>&nbsp;'.
         '<form name="dirs" method="post" action="'.$formaction.
         '" target="_parent"><tt><b>'.
         &Apache::lonhtmlcommon::crumbs($uname.$thisdisfn.'/','_top','/priv','','+1',1)."</b></tt><br />".
@@ -217,9 +217,10 @@ sub startpage {
     }
 
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
+    my $doctitle = 'LON-CAPA '.&mt('Construction Space');
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
-top.document.title = '$esc_thisdisfn/ - LON-CAPA Construction Space';
+top.document.title = '$esc_thisdisfn/ - $doctitle';
 // Store directory location for menu bar to find
 
 parent.lastknownpriv='/~$uname$esc_thisdisfn/';
@@ -369,6 +370,7 @@ sub dircontrols {
 				       updc => 'Upload a new document',
 				       pick => 'Please select an action to perform using the new filename',
                                       );
+    my $mytype = $lt{'type'}; # avoid conflict with " and ' in javascript
     $r->print(<<END);
         <table id="LC_cstr_controls">
          <tr>
@@ -429,7 +431,7 @@ sub dircontrols {
                     <option value="newtaskfile">$lt{'nbt'}:</option>
                     <option value="newlibraryfile">$lt{'nlib'}:</option>
 	            <option value="newdir">$lt{'nsub'}:</option>
-		  </select>&nbsp;<input type="text" name="newfilename" value="Type Name Here" onfocus="if (this.value == 'Type Name Here') this.value=''" />&nbsp;<input type="button" value="Go" onclick="validate_go();" />
+		  </select>&nbsp;<input type="text" name="newfilename" value="$lt{'type'}" onfocus="if (this.value == '$mytype') this.value=''" />&nbsp;<input type="button" value="Go" onclick="validate_go();" />
 		 </span>
 		</form>
 	  </td>
