@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.239 2008/06/30 18:10:24 bisitz Exp $
+# $Id: lonpublisher.pm,v 1.241 2008/07/26 19:05:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -123,6 +123,7 @@ use Apache::loncacc;
 use DBI;
 use Apache::lonnet;
 use Apache::loncommon();
+use Apache::lonhtmlcommon;
 use Apache::lonmysql;
 use Apache::lonlocal;
 use Apache::loncfile;
@@ -325,7 +326,7 @@ string which presents the form field (foreseeably inside
 #########################################
 #########################################
 sub textfield {
-    my ($title,$name,$value)=@_;
+    my ($title,$name,$value,$noline)=@_;
     $value=~s/^\s+//gs;
     $value=~s/\s+$//gs;
     $value=~s/\s+/ /gs;
@@ -333,11 +334,11 @@ sub textfield {
     $env{'form.'.$name}=$value;
     return "\n".&Apache::lonhtmlcommon::row_title($title)
            .'<input type="text" name="'.$name.'" size="80" value="'.$value.'" />'
-           .&Apache::lonhtmlcommon::row_closure();
+           .&Apache::lonhtmlcommon::row_closure($noline);
 }
 
 sub text_with_browse_field {
-    my ($title,$name,$value,$restriction)=@_;
+    my ($title,$name,$value,$restriction,$noline)=@_;
     $value=~s/^\s+//gs;
     $value=~s/\s+$//gs;
     $value=~s/\s+/ /gs;
@@ -352,7 +353,7 @@ sub text_with_browse_field {
 	  .'<a href="javascript:opensearcher(\'pubform\',\''.$name.'\');">'
           .&mt('Search')
           .'</a>'
-          .&Apache::lonhtmlcommon::row_closure();
+          .&Apache::lonhtmlcommon::row_closure($noline);
 }
 
 sub hiddenfield {
@@ -1237,7 +1238,9 @@ END
                 .'<input type="button" value="'.&mt('check all').'" onclick="javascript:checkAll(document.pubform.keywords)" />'
                 .'<input type="button" value="'.&mt('uncheck all').'" onclick="javascript:uncheckAll(document.pubform.keywords)" />'
                 .'</p><br />'
-                .'<table border="2"><tr>';
+                .&Apache::loncommon::start_data_table()
+                .&Apache::loncommon::start_data_table_row();
+
     my $colcount=0;
 
     foreach (sort keys %keywords) {
@@ -1260,7 +1263,8 @@ END
     }
     $env{'form.keywords'}=~s/\,$//;
 
-    $keywordout.='</tr></table>'
+    $keywordout.=&Apache::loncommon::end_data_table_row()
+                 .&Apache::loncommon::end_data_table()
                  .&Apache::lonhtmlcommon::row_closure();
 
     $intr_scrout.=$keywordout;
@@ -1309,9 +1313,12 @@ END
 
     $intr_scrout.=&hiddenfield('lastrevisiondate',time);
 
-
+    my $pubowner_last;
+    if ($style eq 'prv') {
+        $pubowner_last = 1;
+    }
     $intr_scrout.=&textfield('Publisher/Owner','owner',
-			     $metadatafields{'owner'});
+			     $metadatafields{'owner'},$pubowner_last);
 
 # ---------------------------------------------- Retrofix for unused copyright
     if ($metadatafields{'copyright'} eq 'free') {
@@ -1362,7 +1369,7 @@ END
                      .&Apache::lonhtmlcommon::row_closure(1);
         $intr_scrout.=&text_with_browse_field('Suggested Replacement for Obsolete File',
 				    'obsoletereplacement',
-				    $metadatafields{'obsoletereplacement'});
+				    $metadatafields{'obsoletereplacement'},'',1);
     } else {
 	$intr_scrout.=&hiddenfield('copyright','private');
     }
@@ -1388,7 +1395,7 @@ END
 	&hiddenfield('obsolete',1).
 	&text_with_browse_field('Suggested Replacement for Obsolete File',
 				    'obsoletereplacement',
-				    $metadatafields{'obsoletereplacement'});
+				    $metadatafields{'obsoletereplacement'},'',1);
    }
     if (!$batch) {
 	$scrout.=$intr_scrout
@@ -2148,32 +2155,30 @@ ENDCAPTION
 
         $r->print(&Apache::lonhtmlcommon::row_title(&mt('Target'))
                  .'<tt>'.$thisdistarget.'</tt>'
-                 .&Apache::lonhtmlcommon::row_closure()
                  );
-
 # SB - ToDo:   
 	if (($cuname ne $env{'user.name'})||($cudom ne $env{'user.domain'})) {
 #           $r->print(&Apache::lonhtmlcommon::row_title('<span class="LC_warning">'.&mt('Co-Author').'</span>')
-            $r->print(&Apache::lonhtmlcommon::row_title(&mt('Co-Author'))
+            $r->print(&Apache::lonhtmlcommon::row_closure()
+                     .&Apache::lonhtmlcommon::row_title(&mt('Co-Author'))
                      .'<span class="LC_warning">'
 		     .&mt('[_1] at [_2]',$cuname,$cudom)
                      .'</span>'
-                     .&Apache::lonhtmlcommon::row_closure()
                      );
 	}
 
 	if (&Apache::loncommon::fileembstyle($thistype) eq 'ssi') {
-            $r->print(&Apache::lonhtmlcommon::row_title(&mt('Diffs')));
+            $r->print(&Apache::lonhtmlcommon::row_closure()
+                     .&Apache::lonhtmlcommon::row_title(&mt('Diffs')));
 	    $r->print(<<ENDDIFF);
 <a href='javascript:void(window.open("/adm/diff?filename=/~$cuname/$thisdisfn&versiontwo=priv","cat","height=300,width=500,scrollbars=1,resizable=1,menubar=0,location=1"))'>
 ENDDIFF
-            $r->print(&mt('Diffs with Current Version').'</a>'
-                     .&Apache::lonhtmlcommon::row_closure()
-                     );
-
+            $r->print(&mt('Diffs with Current Version').'</a>');
 	}
-
-        $r->print(&Apache::lonhtmlcommon::end_pick_box());
+        
+        $r->print(&Apache::lonhtmlcommon::row_closure(1)
+                 .&Apache::lonhtmlcommon::end_pick_box()
+                 );
   
 # ------------------ Publishing from $thisfn to $thistarget with $thisembstyle.
 
