@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Unauthorized to access construction space
 #
-# $Id: lonunauthorized.pm,v 1.6 2006/12/06 22:22:39 albertel Exp $
+# $Id: lonunauthorized.pm,v 1.7 2007/03/02 23:18:19 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -60,7 +60,7 @@ sub handler {
         my $ownerhome=&Apache::lonnet::homeserver($ownername,$ownerdomain);
         unless ($ownerhome eq 'no_host') {
 	    $r->print(
- "<p>".&mt('Please log into')." <tt>".$Apache::lonnet::hostname{$ownerhome}.
+ "<p>".&mt('Please log into')." <tt>".&Apache::lonnet::hostname($ownerhome).
  "</tt> ".&mt('to edit.')."</p>");
         }
     } else {
