@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.84 2007/08/14 19:32:35 albertel Exp $
+# $Id: lontexconvert.pm,v 1.87 2008/02/06 10:16:00 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -108,6 +108,14 @@ sub convert_real {
     $xmlstring=~s/^\s*\<br clear\=\"all\"/\<br/s;
     $xmlstring=~s/^\s*//;
     $xmlstring=~s/\s*$//;
+    #
+    # \rightleftharpoons is not converted by tth but maps
+    # reasonably well to &#8660;.  If we get many more of these,
+    # we're going to need to have a translation sub.
+    #
+    my $lrharpoon = pack("U", 0x21cc);
+    $xmlstring=~s/\\rightleftharpoons/$lrharpoon/g;
+
     &Apache::lonxml::end_alarm();
     return ($xmlstring,$errorstring);
 }
