@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.473.2.1 2008/03/21 18:52:28 raeburn Exp $
+# $Id: lonxml.pm,v 1.481 2008/06/25 12:00:37 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -718,6 +718,7 @@ sub init_safespace {
   $safeeval->permit(":base_math");
   $safeeval->permit("sort");
   $safeeval->permit("time");
+  $safeeval->permit("caller");
   $safeeval->deny("rand");
   $safeeval->deny("srand");
   $safeeval->deny(":base_io");
@@ -737,6 +738,9 @@ sub init_safespace {
   $safehole->wrap(\&Apache::caparesponse::capa_formula_fix,$safeeval,
 		  '&capa_formula_fix');
 
+  $safehole->wrap(\&Apache::lonlocal::locallocaltime,$safeeval,
+                  '&locallocaltime');
+
   $safehole->wrap(\&Math::Cephes::asin,$safeeval,'&asin');
   $safehole->wrap(\&Math::Cephes::acos,$safeeval,'&acos');
   $safehole->wrap(\&Math::Cephes::atan,$safeeval,'&atan');
@@ -1080,6 +1084,7 @@ Optional Arguments:
 
 sub increment_counter {
     my ($increment, $part_response) = @_;
+    if ($env{'form.grade_noincrement'}) { return; }
     if (!defined($increment) || $increment le 0) {
 	$increment = 1;
     }
@@ -1121,7 +1126,7 @@ sub init_counter {
 }
 
 sub store_counter {
-    &Apache::lonnet::appenv(('form.counter' => $Apache::lonxml::counter));
+    &Apache::lonnet::appenv({'form.counter' => $Apache::lonxml::counter});
     $Apache::lonxml::counter_changed=0;
     return '';
 }
@@ -1142,7 +1147,7 @@ sub store_counter {
 
     sub restore_problem_counter {
 	if (defined($state)) {
-	    &Apache::lonnet::appenv(('form.counter' => $state));
+	    &Apache::lonnet::appenv({'form.counter' => $state});
 	}
     }
     sub get_problem_counter {
@@ -1379,7 +1384,7 @@ sub writeallows {
  	        &Apache::lonnet::hreflocation($thisdir,&unescape($_))}=$thisurl;
     }
     @extlinks=();
-    &Apache::lonnet::appenv(%httpref);
+    &Apache::lonnet::appenv(\%httpref);
 }
 
 sub register_ssi {
@@ -1496,6 +1501,30 @@ sub verify_html {
     return '';
 }
 
+sub renderingoptions {
+    my %langchoices=('' => '');
+    foreach (&Apache::loncommon::languageids()) {
+        if (&Apache::loncommon::supportedlanguagecode($_)) {
+            $langchoices{&Apache::loncommon::supportedlanguagecode($_)}
+                       = &Apache::loncommon::plainlanguagedescription($_);
+        }
+    }
+    return
+       '<span class="LC_nobreak">'.
+       &mt('Language:').' '.
+       &Apache::loncommon::select_form($env{'form.languages'},'languages',
+                                                     %langchoices).'
+     </span>
+     <span class="LC_nobreak">'.
+       &mt('Math Rendering:').' '.
+       &Apache::loncommon::select_form($env{'form.texengine'},'texengine',
+                                                     ('' => '',
+                                                      'tth' => 'tth (Tex-to-HTML)',
+                                                      'jsMath' => 'jsMath',
+                                                      'mimetex' => 'mimetex (Convert to Images)')).'
+     </span>';
+}
+
 sub inserteditinfo {
       my ($filecontents, $filetype, $filename)=@_;
       $filecontents = &HTML::Entities::encode($filecontents,'<>&"');
@@ -1761,7 +1790,8 @@ sub display_title {
 	    $title = $env{'request.filename'};
 	    $title = substr($title, rindex($title, '/') + 1);
 	}
-	$result = "<script type='text/javascript'>top.document.title = '$title - LON-CAPA Construction Space';</script>";
+        $result = "<script type='text/javascript'>top.document.title = '$title - LON-CAPA "
+                  .&mt('Construction Space')."';</script>";
     }
     return $result;
 }
@@ -1815,7 +1845,7 @@ sub error {
 	# If printing in construction space, put the error inside <pre></pre>
 	push(@Apache::lonxml::error_messages,
 	     $Apache::lonxml::warnings_error_header.
-	     "<b>ERROR:</b>".join("<br />\n",@errors)."<br />\n");
+             "<b>".&mt('ERROR:')."</b>".join("<br />\n",@errors)."<br />\n");
 	$Apache::lonxml::warnings_error_header='';
     } else {
 	my $errormsg;
@@ -1825,7 +1855,9 @@ sub error {
 	    $errormsg=&mt("An error occured while processing this resource. The author has been notified.");
 	}
 	my $host=$Apache::lonnet::perlvar{'lonHostID'};
-	push(@errors, "The error occurred on host <tt>$host</tt>");
+	push(@errors,
+        &mt("The error occurred on host [_1]",
+             "<tt>$host</tt>"));
 
 	my $msg = join('<br />', @errors);
 
