@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.143 2007/08/30 22:56:43 albertel Exp $
+# $Id: scripttag.pm,v 1.147 2007/11/17 01:51:11 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -30,7 +30,8 @@ package Apache::scripttag;
 
 use strict;
 use Apache::lonnet;
-use Apache::style;
+use Apache::lonlocal;
+use Apache::style();
 
 #Globals
 # this used to pass around the standard callsub arguments to a tag func
@@ -136,16 +137,19 @@ sub start_script {
 
 	    $uname =~s/\W//g;
 	    $udom  =~s/\W//g;
+	    my $function_name = 
+		join('_','LONCAPA_scriptvars',$uname,$udom,
+		     $env{'form.counter'},$Apache::lonxml::curdepth);
 	    my $script_var ="<script type=\"text/javascript\">
 // <![CDATA[
-    function LONCAPA_scriptvars_".$uname."_".$udom."_"."$Apache::lonxml::curdepth() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page<pre>";
+    function $function_name() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page<pre>";
 	    my $listing=&Apache::run::dump($target,$safeeval);
 	    $listing=~s/\\/\\\\/g;
 	    $listing=~s/\'/\\\'/g;
 	    $script_var.=$listing;
 	    $script_var.= "<\\/pre>$end_page');newWindow.document.close();newWindow.focus()}
 // ]]>
-</script><a href=\"javascript:LONCAPA_scriptvars_".$uname."_".$udom."_$Apache::lonxml::curdepth();void(0);\">Script Vars</a><br />";
+</script><a href=\"javascript:$function_name();void(0);\">".&mt('Script Vars')."</a><br />";
 	    &Apache::lonxml::add_script_result($script_var);
 	}
     } elsif ($target eq "edit" ) {
@@ -159,7 +163,7 @@ sub start_script {
     }
   } else {
       my $bodytext=&Apache::lonxml::get_all_text_unbalanced("/script",$parser);
-      if ($target ne "meta" && $target ne 'tex') {
+      if ($target ne "meta" && $target ne 'tex' && $target ne 'answer') {
 	  $result = $token->[4];
 	  $result.=$bodytext;
       }
@@ -242,7 +246,7 @@ sub start_scriptlib {
     my $script=&Apache::lonnet::getfile($location);
     if ($script == -1) {
       if ($target eq 'edit') {
-        $error='</tr><tr><td>Errors</td><td colspan="2"><b> Unable to find <i>'.$location.'</i></b></td>'."\n";
+        $error='</tr><tr><td>'.&mt('Errors').'</td><td colspan="2"><b>'.&mt(' Unable to find [_1]','<span class="LC_filename">'.$location.'</span>').'</b></td>'."\n";
       } else {
 	&Apache::lonxml::error("<b> Unable to find <i>$location</i> for scriptlib</b>");
 	return "";
@@ -329,11 +333,13 @@ sub start_window {
 	$result.=&Apache::edit::text_arg('Text of Link:','linktext',$token,70);
 	$result.=&Apache::edit::text_arg('Height:','height',$token,5);
 	$result.=&Apache::edit::text_arg('Width:','width',$token,5);
+	$result.=&Apache::edit::text_arg('Mime Type:','mimetype',$token,5);
 	$result .=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
 	my $constructtag=&Apache::edit::get_new_args($token,$parstack,
 						     $safeeval,'linktext',
-						     'width','height');
+						     'width','height',
+						     'mimetype');
 	if ($constructtag) { $result=&Apache::edit::rebuild_tag($token); }
     }
     return $result;  
@@ -353,19 +359,26 @@ sub end_window {
     if (!$width) { $width='500'; }
     my $height= &Apache::lonxml::get_param('height',$parstack,$safeeval);
     if (!$height) { $height='200'; }
+    my $mimetype= &Apache::lonxml::get_param('mimetype',$parstack,$safeeval)
+	          || 'text/html';
 
-    my $start_page =
-	&Apache::loncommon::start_page($linktext, undef,
-				       {'only_body' => 1,
-					'bgcolor'   => '#FFFFFF',
-					'js_ready'  => 1,});
-    my $end_page =
-	&Apache::loncommon::end_page({'js_ready' => 1,});
+    my ($start_page,$end_page);
+    if ($mimetype eq 'text/html') {
+	$start_page =
+	    &Apache::loncommon::start_page($linktext, undef,
+					   {'only_body' => 1,
+					    'bgcolor'   => '#FFFFFF',
+					    'js_ready'  => 1,});
+	$end_page =
+	    &Apache::loncommon::end_page({'js_ready' => 1,});
+    }
     $result = "<script type=\"text/javascript\">
 //<!--
  function LONCAPA_newwindow_$Apache::lonxml::curdepth() {
+newWindow=open(".&Apache::lonhtmlcommon::javascript_nothing().",'new_W');
+newWindow.close();
 newWindow=open(".&Apache::lonhtmlcommon::javascript_nothing().",'new_W','width=$width,height=$height,scrollbars=1');
-newWindow.".&Apache::lonhtmlcommon::javascript_docopen().";
+newWindow.".&Apache::lonhtmlcommon::javascript_docopen($mimetype).";
 newWindow.document.writeln('$start_page $output $end_page');
 newWindow.document.close();}
 //-->
@@ -404,7 +417,7 @@ sub start_import {
     push(@Apache::inputtags::import,$id);
     push(@Apache::inputtags::importlist,$id);
 
-	&Apache::lonxml::newparser($parser,\$file,$dir);
+    &Apache::lonxml::newparser($parser,\$file,$dir);
 
   } elsif ($target eq "edit" ) {
     $result.=&Apache::edit::tag_start($target,$token);
