@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.87 2007/01/16 21:10:55 albertel Exp $
+# $Id: lonratedt.pm,v 1.88 2007/07/11 20:32:01 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -274,7 +274,7 @@ function idxopen(mode) {
    var options="scrollbars=1,resizable=1,menubar=0,location=1,toolbar=1";
    idxmode=mode;
    idxflag=1;
-   idx=open('$resurl/?launch=1&mode=$mode&catalogmode='+mode,'idxout',options);
+   idx=open('$resurl/?inhibitmenu=yes&launch=1&mode=$mode&catalogmode='+mode,'idxout',options);
    idx.focus();
 }
 
@@ -282,7 +282,7 @@ function idxopen(mode) {
 function groupopen(url,recover,bookmarks) {
    var options="scrollbars=1,resizable=1,menubar=0";
    idxflag=1;
-   idx=open("/adm/groupsort?mode=$mode&recover="+recover+"&readfile="+url+"&bookmarks="+bookmarks,"idxout",options);
+   idx=open("/adm/groupsort?inhibitmenu=yes&mode=$mode&recover="+recover+"&readfile="+url+"&bookmarks="+bookmarks,"idxout",options);
    idx.focus();
 }
 
@@ -291,7 +291,7 @@ function srchopen(mode) {
    var options="scrollbars=1,resizable=1,menubar=0";
    srchmode=mode;
    srchflag=1;
-   srch=open("/adm/searchcat?launch=1&mode=$mode&catalogmode="+mode,"srchout",options);
+   srch=open("/adm/searchcat?inhibitmenu=yes&launch=1&mode=$mode&catalogmode="+mode,"srchout",options);
    srch.focus();
 }
 // ----------------------------------------------------- launch indexer browser
@@ -326,6 +326,7 @@ function idxcheck(mode) {
         if (editbrowser == null) {
             url += 'launch=1&';
         }
+        url += 'inhibitmenu=yes&';
         url += 'catalogmode=interactive&';
         url += 'mode=edit&';
         url += 'form=' + formname + '&';
